# DiscordOAuth2
automatically follows through with the requests for Discord OAuth

[![Documentation Status](https://readthedocs.org/projects/async-disoauth2/badge/?version=latest)](https://async-disoauth2.readthedocs.io/en/latest/?badge=latest)

***

## Features
- Makes a Authorization Url automatically, using the client ID, redirect_uri, and the scopes you want
- Can get:
  - The access token
  - The user
  - The user's guilds

***

## What I'm working on for version 2.0.0

- [x] Get Guilds
  - Released in version 1.1
  - [x] Errors, will be fixed in version 1.1.4
    - Found error in the scope part of the url creation
- [x] Models
  - [x] User Object
    - [x] Errors, fixed in version 1.1.3
  - [x] Guild Object
    - Released in version 1.2
- [x] Bot OAuth
    - Released in version 1.3
- [ ] Functioning CLI

***

### Useful Links:

- [License](https://github.com/disoauth/DiscoAuth/blob/main/LICENSE)
- [Contributing & Guidelines](https://github.com/disoauth/DiscoAuth/blob/main/CONTRIBUTING.md)
- [Roadmap](https://github.com/orgs/disoauth/projects/1)

***

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

***

## License

This project is under the [MIT License](https://en.wikipedia.org/wiki/MIT_License)
